==> scanner_view-0.1.3.tar.gz: lib/scanner_view.dart <==
import 'dart:async';
import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:image_picker/image_picker.dart';
import 'package:fluttertoast/fluttertoast.dart';

typedef EhsureScannerCallback = FutureOr<void> Function(String scanResult);
class ScannerView {
  static const String SCANNER_METHOD_CHANNEL = "ehsure_scanner_channel";
  static const String SCANNER_METHOD = "scanResult";
  static const String SCANNER_RESUME_METHOD = "scanResume";
  static const String SCANNER_VIEW_TYPE_ID = "ehsure_scanner_view";
  static const String SCANNER_IMAGE_PATH = "qrImage";
  static MethodChannel channel = MethodChannel(ScannerView.SCANNER_METHOD_CHANNEL);

  static Future<void> getScanResult (BuildContext context, {@required EhsureScannerCallback callback, bool isSingle = true, bool isCanDecodeFromPhoto = true}) async {
      await Navigator.push(context, MaterialPageRoute(builder: (context) {
        return PlatformScannerView(callback: callback, isSingle: isSingle, isCanDecodeFromPhoto: isCanDecodeFromPhoto,);
      }));
  }

}

class PlatformScannerView extends StatefulWidget {
  final EhsureScannerCallback callback;
  final bool isSingle;
  final bool isCanDecodeFromPhoto;
  PlatformScannerView({Key key, this.callback, this.isSingle, this.isCanDecodeFromPhoto = true}): super(key: key);
  @override
  _PlatformScannerViewState createState() => _PlatformScannerViewState();
}

class _PlatformScannerViewState extends State<PlatformScannerView> {

  final MethodChannel channel = MethodChannel(ScannerView.SCANNER_METHOD_CHANNEL);
  final ImagePicker _picker = ImagePicker();
  var firstLoad = true;

  @override
  void initState() {
    super.initState();
    handleChannel();
  }

  Future<String> getQRImageResult(String path) async {
    String qrResult = await channel.invokeMethod(ScannerView.SCANNER_IMAGE_PATH, path);
    return qrResult;
  }

  handleChannel() {
    channel.setMethodCallHandler((MethodCall call) async {
      if (call?.method == ScannerView.SCANNER_METHOD) {
        if (widget.isSingle) {
          Navigator.of(context).pop();
          widget.callback(call.arguments.toString());
          return null;
        }
        await widget.callback(call.arguments.toString());
        if (Platform.isIOS) {
          await setScanResume();
        } else {
          return 'success';
        }
      }
      return null;
    });
  }

  Future<void> setScanResume() async {
    return channel.invokeMethod(ScannerView.SCANNER_RESUME_METHOD);
  }

  Future<void> setPauseScan() async {
    return channel.invokeMethod("scanPause");
  }

  Future<String> showInputDialog() {
    String inputString;
    return showDialog<String>(
        context: context,
        builder: (context) {
          return AlertDialog(
            title: Text("手动输入"),
            content: Column(
              mainAxisSize: MainAxisSize.min,
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                Row(
                  mainAxisSize: MainAxisSize.min,
                  children: <Widget>[
                    Expanded(
                      child: TextField(
                        decoration: InputDecoration(hintText: ""),
                        onChanged: (value) {
                          inputString = value;
                        },
                        keyboardType: TextInputType.url,
                      ),
                    )
                  ],
                ),
              ],
            ),
            actions: <Widget>[
              FlatButton(
                child: Text('取消'),
                onPressed: () {
                  Navigator.of(context).pop();
                },
              ),
              FlatButton(
                child: Text('确定'),
                onPressed: () {
                  Navigator.of(context).pop(inputString);
                },
              )
            ],
          );
        });
  }

  @override
  Widget build(BuildContext context) {
    Widget pView;
    if (Platform.isIOS) {
      pView = UiKitView(
        viewType: ScannerView.SCANNER_VIEW_TYPE_ID,
        gestureRecognizers: <Factory<OneSequenceGestureRecognizer>>[
          new Factory<OneSequenceGestureRecognizer>(
                () => new EagerGestureRecognizer(),
          ),
        ].toSet(),
      );
    } else {
      pView = AndroidView(
        viewType: ScannerView.SCANNER_VIEW_TYPE_ID,
        gestureRecognizers: <Factory<OneSequenceGestureRecognizer>>[
          new Factory<OneSequenceGestureRecognizer>(
                () => new EagerGestureRecognizer(),
          ),
        ].toSet(),
      );
    }
    return Scaffold(
      body: Container(
        child: Stack(
          fit: StackFit.expand,
          children: <Widget>[
            pView,
            Positioned(
              left: 0,
              right: 0,
              top: 100,
              height: 50,
              child: Center(child: FlatButton(
                onPressed: () async {
                  String result = await showInputDialog();
                  if (result != null) {
                    if (widget.isSingle) {
                      Navigator.of(context).pop();
                    }
                    widget.callback(result);
                  }
                },
                child: Text("手动输入", style: TextStyle(color: Colors.white,fontSize: 16),),)
              ),
            ),
            Positioned(
              left: 0,
              right: 0,
              bottom: 110,
              height: 50,
              child: Center(child: Offstage(
                offstage: !widget.isCanDecodeFromPhoto,
                child: FlatButton(
                  onPressed: () async {
                    PickedFile img = await _picker.getImage(source: ImageSource.gallery);
                    String result = await getQRImageResult(img.path);
                    if (widget.isSingle) {
                      Navigator.of(context).pop();
                    }
                    if (result == null) {
                      Fluttertoast.showToast(msg: "二维码解析失败");
                    } else {
                      widget.callback(result);
                    }
                  },
                  child: Text("相册选择", style: TextStyle(color: Colors.white,fontSize: 16),),),
              )
              ),
            ),
            Positioned(
              child: AppBar(
                  leading: BackButton(),
                  elevation: 0,
                  backgroundColor: Colors.transparent,
                  brightness: Brightness.dark),
              top: 0,
              right: 0,
              left: 0,
            ),
          ],
        ),
      ),
    );
  }
}

==> scanner_view-1.0.2.tar.gz: lib/scanner_view.dart <==
import 'dart:async';
import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:image_picker/image_picker.dart';
import 'package:fluttertoast/fluttertoast.dart';

typedef EhsureScannerCallback = FutureOr<void> Function(String scanResult);
class ScannerView {
  static const String SCANNER_METHOD_CHANNEL = "ehsure_scanner_channel";
  static const String SCANNER_METHOD = "scanResult";
  static const String SCANNER_RESUME_METHOD = "scanResume";
  static const String SCANNER_VIEW_TYPE_ID = "ehsure_scanner_view";
  static const String SCANNER_IMAGE_PATH = "qrImage";
  static MethodChannel channel = MethodChannel(ScannerView.SCANNER_METHOD_CHANNEL);

  static Future<void> getScanResult (BuildContext context, {@required EhsureScannerCallback callback, bool isSingle = true, bool isCanDecodeFromPhoto = true}) async {
      await Navigator.push(context, MaterialPageRoute(builder: (context) {
        return PlatformScannerView(callback: callback, isSingle: isSingle, isCanDecodeFromPhoto: isCanDecodeFromPhoto,);
      }));
  }

}

class PlatformScannerView extends StatefulWidget {
  final EhsureScannerCallback callback;
  final bool isSingle;
  final bool isCanDecodeFromPhoto;
  PlatformScannerView({Key key, this.callback, this.isSingle, this.isCanDecodeFromPhoto = true}): super(key: key);
  @override
  _PlatformScannerViewState createState() => _PlatformScannerViewState();
}

class _PlatformScannerViewState extends State<PlatformScannerView> {

  final MethodChannel channel = MethodChannel(ScannerView.SCANNER_METHOD_CHANNEL);
  final ImagePicker _picker = ImagePicker();
  var firstLoad = true;

  @override
  void initState() {
    super.initState();
    handleChannel();
  }

  Future<String> getQRImageResult(String path) async {
    String qrResult = await channel.invokeMethod(ScannerView.SCANNER_IMAGE_PATH, path);
    return qrResult;
  }

  handleChannel() {
    channel.setMethodCallHandler((MethodCall call) async {
      if (call?.method == ScannerView.SCANNER_METHOD) {
        if (widget.isSingle) {
          Navigator.of(context).pop();
          widget.callback(call.arguments.toString());
          return null;
        }
        await widget.callback(call.arguments.toString());
        if (Platform.isIOS) {
          await setScanResume();
        } else {
          return 'success';
        }
      }
      return null;
    });
  }

  Future<void> setScanResume() async {
    return channel.invokeMethod(ScannerView.SCANNER_RESUME_METHOD);
  }

  Future<void> setPauseScan() async {
    return channel.invokeMethod("scanPause");
  }

  Future<String> showInputDialog() {
    String inputString;
    return showDialog<String>(
        context: context,
        builder: (context) {
          return AlertDialog(
            title: Text("手动输入"),
            content: Column(
              mainAxisSize: MainAxisSize.min,
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                Row(
                  mainAxisSize: MainAxisSize.min,
                  children: <Widget>[
                    Expanded(
                      child: TextField(
                        decoration: InputDecoration(hintText: ""),
                        onChanged: (value) {
                          inputString = value;
                        },
                        keyboardType: TextInputType.url,
                      ),
                    )
                  ],
                ),
              ],
            ),
            actions: <Widget>[
              TextButton(
                child: Text('取消'),
                onPressed: () {
                  Navigator.of(context).pop();
                },
              ),
              TextButton(
                child: Text('确定'),
                onPressed: () {
                  Navigator.of(context).pop(inputString);
                },
              )
            ],
          );
        });
  }

  @override
  Widget build(BuildContext context) {
    Widget pView;
    if (Platform.isIOS) {
      pView = UiKitView(
        viewType: ScannerView.SCANNER_VIEW_TYPE_ID,
        gestureRecognizers: <Factory<OneSequenceGestureRecognizer>>[
          new Factory<OneSequenceGestureRecognizer>(
                () => new EagerGestureRecognizer(),
          ),
        ].toSet(),
      );
    } else {
      pView = AndroidView(
        viewType: ScannerView.SCANNER_VIEW_TYPE_ID,
        gestureRecognizers: <Factory<OneSequenceGestureRecognizer>>[
          new Factory<OneSequenceGestureRecognizer>(
                () => new EagerGestureRecognizer(),
          ),
        ].toSet(),
      );
    }
    return Scaffold(
      body: Container(
        child: Stack(
          fit: StackFit.expand,
          children: <Widget>[
            pView,
            Positioned(
              left: 0,
              right: 0,
              top: 100,
              height: 50,
              child: Center(child: TextButton(
                onPressed: () async {
                  String result = await showInputDialog();
                  if (result != null) {
                    if (widget.isSingle) {
                      Navigator.of(context).pop();
                    }
                    widget.callback(result);
                  }
                },
                child: Text("手动输入", style: TextStyle(color: Colors.white,fontSize: 16),),)
              ),
            ),
            Positioned(
              left: 0,
              right: 0,
              bottom: 110,
              height: 50,
              child: Center(child: Offstage(
                offstage: !widget.isCanDecodeFromPhoto,
                child: TextButton(
                  onPressed: () async {
                    XFile img = await _picker.pickImage(source: ImageSource.gallery);
                    String result = await getQRImageResult(img.path);
                    if (widget.isSingle) {
                      Navigator.of(context).pop();
                    }
                    if (result == null) {
                      Fluttertoast.showToast(msg: "二维码解析失败");
                    } else {
                      widget.callback(result);
                    }
                  },
                  child: Text("相册选择", style: TextStyle(color: Colors.white,fontSize: 16),),),
              )
              ),
            ),
            Positioned(
              child: AppBar(
                  leading: BackButton(),
                  elevation: 0,
                  backgroundColor: Colors.transparent),
              top: 0,
              right: 0,
              left: 0,
            ),
          ],
        ),
      ),
    );
  }
}
